unit uMain;

{$INCLUDE 'h2lrf.inc'}

interface

uses
  SysUtils, Classes,
  uConsoleApp, uCompatibility, uFunc;

type
  TH2LRF = class(TConsoleApp)
    private
      Options: TConvertOptions;
    protected
      function AppTitle: string; override;
      function AppVersion: string; override;
      function DoExecute: integer; override;
      procedure ShowSyntax(const Error: string = ''); override;
      procedure ParamInitialize; override;
      function ProcessWildCardFile(const FileName: string; const SearchRec: TSearchRec): boolean; override;
    public
      constructor Create; override;
      destructor Destroy; override;
    end;

const
  RESCODE_NOTHINGTODO = 1;
  
implementation

{ TH2LRF }

constructor TH2LRF.Create;
begin
  inherited;
end;

destructor TH2LRF.Destroy;
begin
  inherited;
end;

function TH2LRF.AppTitle: string;
begin
  Result := 'H2LRF';
end;

function TH2LRF.AppVersion: string;
begin
  Result := {$INCLUDE 'h2lrf.version'} ;
end;

procedure TH2LRF.ShowSyntax(const Error: string);
begin
  inherited;
  WriteColored(ccWhite, '<arg> [<arg>] ... <wildcard> [<wildcard>] ...');
  Writeln;
  Writeln;
  WriteColored(ccWhite, ' -h, -?'); Writeln(' ........ show this help screen.');
  WriteColored(ccWhite, ' -r'); Writeln(' ............ recursive scanning of subdirectories.');
  WriteColored(ccWhite, ' -r+'); Writeln(' ........... -r, plus output files maintain subdirs.');
  WriteColored(ccWhite, ' -r-'); Writeln(' ........... disable recursive scanning.');
  WriteColored(ccWhite, ' -t <target>'); Writeln(' ... set conversion target (default=LRF).');
  WriteColored(ccWhite, ' -o <dir>'); Writeln(' ...... set output directory.');
  WriteColored(ccWhite, ' -e <file>'); Writeln(' ..... output errors to <file> and continue.');
  Writeln;
  WriteColored(ccWhite, ' <wildcard>'); Writeln(' .... file(s) to convert.');
  Writeln;
  Writeln('Two special <META> syntaxes are supported:');
  Writeln('  <META NAME="@include" CONTENT="<path>">');
  Writeln('  <META NAME="lrf:@include" CONTENT="<path>">');
  Writeln('      ... include another file here for metadata extraction (can be nested).');
  Writeln('  <META NAME="lrf:<parameter>" CONTENT="<value>">');
  Writeln('      ... specify command line parameter for HTML2LRF, including the leading');
  Writeln('          -- or -. <value> can contain several replacement characters:');
  Writeln('           %% => gets replaced by a single %');
  Writeln('           %r => removes the whole parameter (use to suppress a default)');
  Writeln('           %f => full path to a file from <wildcard> (NOT the included file)');
  Writeln('           %d => drive of the file from <wildcard>');
  Writeln('           %p => full path (including drive) to the file from <wildcard>');
  Writeln('           %n => filename without extension of the file from <wildcard>');
  Writeln('           %x => extension of the file from <wildcard>');
  Writeln('           %e => empty string');
  Writeln('          HTML entities &amp;, &lt;, &gt; and &quot; are also supported.');
  Writeln('Instead of "lrf:" other prefixes for different targets are possible - see');
  Writeln('INI file for possible prefixes; "*:" can also be used for "any target".');
  Writeln;
  Writeln;
end;

procedure TH2LRF.ParamInitialize;
begin
  inherited;
  Options := DefaultOptions;
end;

function TH2LRF.DoExecute: integer;
var
  Param: string;
begin
  Result := RESCODE_NOTHINGTODO;
  if ParamCount = 0 then
    ShowSyntax
  else
    begin
    ParamInitialize;
    while ParamGetNext(Param) do
      if Param[1] = '-' then
        begin
        if (Param = '-?') or (Param = '-h') then
          ShowSyntax
        else if (Param = '-r') then
          Options.InputRecursive := True
        else if (Param = '-r-') then
          begin
          Options.InputRecursive := False;
          Options.OutputRecursive := False;
          end
        else if (Param = '-r+') then
          begin
          Options.InputRecursive := True;
          Options.OutputRecursive := True;
          end
        else if (Param = '-t') then
          if ParamGetNext(Param) then
            begin
            if not SetTarget(Param, Options) then
              ShowSyntax('Invalid target "%s". Check your INI file.');
            end
          else
            ShowSyntax('-t needs a parameter.')
        else if (Param = '-o') then
          if ParamGetNext(Param) then
            Options.OutputDir := Param
          else
            ShowSyntax('-o needs a parameter.')
        else if (Param = '-e') then
          if ParamGetNext(Param) then
            Options.ErrorLogFileName := Param
          else
            ShowSyntax('-e needs a parameter.')
        else if Param[1] = '-' then
          ShowSyntax('Unknown parameter "%s".', [Param]);
        end
      else
        begin
        Param := ExpandFileName(Param);
        {$IFDEF ALLOW_DIRECTORY_WILDCARD}
        if DirectoryExists(Param) then
          begin
          Options.InputDir := Param + '\';
          Options.InputWildCard := '*.htm*';
          end
        else
        {$ENDIF}
          begin
          Options.InputDir := ExtractFilePath(Param);
          Options.InputWildCard := ExtractFileName(Param);
          end;
        if Convert(Options) then
        //if ProcessWildCard(Param, Options.InputRecursive) > 0 then
          Result := RESCODE_OK;
        end;
    if Result = RESCODE_NOTHINGTODO then
      ShowError('No files found.');
    end;
end;

function TH2LRF.ProcessWildCardFile(const FileName: string; const SearchRec: TSearchRec): boolean;
begin
  Result := False;
end;

end.
